@@ -158,4 +158,20 @@ SUPPORTED_DATASETS = {
     "yelp2018": "cogdl.datasets.rec_data.Yelp2018Dataset",
     "ali": "cogdl.datasets.rec_data.AliDataset",
     "amazon-rec": "cogdl.datasets.rec_data.AmazonRecDataset",
+    "Github": "cogdl.datasets.rd2cd_data.Github",
+    "Elliptic": "cogdl.datasets.rd2cd_data.Elliptic",
+    "Film": "cogdl.datasets.rd2cd_data.Film",
+    "Wiki": "cogdl.datasets.rd2cd_data.Wiki",
+    "Clothing": "cogdl.datasets.rd2cd_data.Clothing",
+    "Electronics": "cogdl.datasets.rd2cd_data.Electronics",
+    "Dblp": "cogdl.datasets.rd2cd_data.Dblp",
+    "Yelpchi": "cogdl.datasets.rd2cd_data.Yelpchi",
+    "Alpha": "cogdl.datasets.rd2cd_data.Alpha",
+    "Weibo": "cogdl.datasets.rd2cd_data.Weibo",
+    "bgp": "cogdl.datasets.rd2cd_data.bgp",
+    "ssn5": "cogdl.datasets.rd2cd_data.ssn5",
+    "ssn7": "cogdl.datasets.rd2cd_data.ssn7",
+    "Aids": "cogdl.datasets.rd2cd_data.Aids",
+    "Nba": "cogdl.datasets.rd2cd_data.Nba",
+    "Pokec_z": "cogdl.datasets.rd2cd_data.Pokec_z",
 }
