@@ -3,11 +3,9 @@ import pickle
 
 import numpy as np
 import torch
-from cogdl.data import Data, Dataset
+from cogdl.data import Graph, Dataset
 from cogdl.utils import download_url, untar
 
-from . import register_dataset
-
 
 class GTNDataset(Dataset):
     r"""The network datasets "ACM", "DBLP" and "IMDB" from the
@@ -46,7 +44,7 @@ class GTNDataset(Dataset):
         labels = pickle.load(open(osp.join(folder, "labels.pkl"), "rb"))
         node_features = pickle.load(open(osp.join(folder, "node_features.pkl"), "rb"))
 
-        data = Data()
+        data = Graph()
         data.x = torch.from_numpy(node_features).type(torch.FloatTensor)
 
         num_nodes = edges[0].shape[0]
@@ -103,6 +101,7 @@ class GTNDataset(Dataset):
 
     def apply_to_device(self, device):
         self.data.x = self.data.x.to(device)
+        self.data.y = self.data.y.to(device)
 
         self.data.train_node = self.data.train_node.to(device)
         self.data.valid_node = self.data.valid_node.to(device)
@@ -126,28 +125,25 @@ class GTNDataset(Dataset):
         torch.save(self.data, self.processed_paths[0])
 
     def __repr__(self):
-        return "{}()".format(self.name)
+        return "{}".format(self.name)
 
 
-@register_dataset("gtn-acm")
 class ACM_GTNDataset(GTNDataset):
-    def __init__(self):
+    def __init__(self, data_path="data"):
         dataset = "gtn-acm"
-        path = osp.join("data", dataset)
+        path = osp.join(data_path, dataset)
         super(ACM_GTNDataset, self).__init__(path, dataset)
 
 
-@register_dataset("gtn-dblp")
 class DBLP_GTNDataset(GTNDataset):
-    def __init__(self):
+    def __init__(self, data_path="data"):
         dataset = "gtn-dblp"
-        path = osp.join("data", dataset)
+        path = osp.join(data_path, dataset)
         super(DBLP_GTNDataset, self).__init__(path, dataset)
 
 
-@register_dataset("gtn-imdb")
 class IMDB_GTNDataset(GTNDataset):
-    def __init__(self):
+    def __init__(self, data_path="data"):
         dataset = "gtn-imdb"
-        path = osp.join("data", dataset)
+        path = osp.join(data_path, dataset)
         super(IMDB_GTNDataset, self).__init__(path, dataset)
