@@ -7,9 +7,8 @@ import scipy.sparse as sp
 import torch
 from sklearn.preprocessing import StandardScaler
 
-from cogdl.data import Data, Dataset
-from cogdl.utils import download_url, accuracy, multilabel_f1, bce_with_logits_loss, cross_entropy_loss
-from . import register_dataset
+from cogdl.data import Graph, Dataset
+from cogdl.utils import download_url, Accuracy, MultiLabelMicroF1, BCEWithLogitsLoss, CrossEntropyLoss
 from .planetoid_data import index_to_mask
 
 
@@ -51,7 +50,7 @@ def read_saint_data(folder):
     edge_index_full, edge_attr_full = get_adj(adj_full)
     edge_index_train, edge_attr_train = get_adj(adj_train)
 
-    data = Data(
+    data = Graph(
         x=feats,
         y=labels,
         edge_index=edge_index_full,
@@ -101,10 +100,10 @@ class SAINTDataset(Dataset):
         return self.data
 
     def get_evaluator(self):
-        return multilabel_f1
+        return Accuracy()
 
     def get_loss_fn(self):
-        return bce_with_logits_loss
+        return BCEWithLogitsLoss()
 
     def __repr__(self):
         return "{}()".format(self.name)
@@ -115,114 +114,121 @@ class SAINTDataset(Dataset):
 
 def scale_feats(data):
     scaler = StandardScaler()
-    scaler.fit(data.x.numpy())
-    data.x = torch.from_numpy(scaler.transform(data.x)).float()
+    feats = data.x.numpy()
+    scaler.fit(feats)
+    feats = torch.from_numpy(scaler.transform(feats)).float()
+    data.x = feats
     return data
 
 
-@register_dataset("yelp")
+# def scale_feats(data):
+#     x_sum = torch.sum(data.x, dim=1)
+#     x_rev = x_sum.pow(-1).flatten()
+#     x_rev[torch.isnan(x_rev)] = 0.0
+#     x_rev[torch.isinf(x_rev)] = 0.0
+#     data.x = data.x * x_rev.unsqueeze(-1).expand_as(data.x)
+#     return data
+
+
 class YelpDataset(SAINTDataset):
-    def __init__(self):
+    def __init__(self, data_path="data"):
         dataset = "Yelp"
         url = "https://cloud.tsinghua.edu.cn/d/7218cc013c9a40159306/files/?p=%2F{}&dl=1"
-        path = osp.join("data", dataset)
+        path = osp.join(data_path, dataset)
         if not osp.exists(path):
             SAINTDataset(path, dataset, url)
         super(YelpDataset, self).__init__(path, dataset, url)
         self.data = scale_feats(self.data)
 
     def get_evaluator(self):
-        return multilabel_f1
+        return MultiLabelMicroF1()
 
     def get_loss_fn(self):
-        return bce_with_logits_loss
+        return BCEWithLogitsLoss()
 
 
-@register_dataset("amazon-s")
 class AmazonDataset(SAINTDataset):
-    def __init__(self):
+    def __init__(self, data_path="data"):
         dataset = "AmazonSaint"
         url = "https://cloud.tsinghua.edu.cn/d/ae4b2c4f59bd41be9b0b/files/?p=%2F{}&dl=1"
-        path = osp.join("data", dataset)
+        path = osp.join(data_path, dataset)
         if not osp.exists(path):
             SAINTDataset(path, dataset, url)
         super(AmazonDataset, self).__init__(path, dataset, url)
         self.data = scale_feats(self.data)
 
     def get_evaluator(self):
-        return multilabel_f1
+        return MultiLabelMicroF1()
 
     def get_loss_fn(self):
-        return bce_with_logits_loss
+        return BCEWithLogitsLoss()
 
 
-@register_dataset("flickr")
-class FlickrDatset(SAINTDataset):
-    def __init__(self):
+class FlickrDataset(SAINTDataset):
+    def __init__(self, data_path="data"):
         dataset = "Flickr"
         url = "https://cloud.tsinghua.edu.cn/d/d3ebcb5fa2da463b8213/files/?p=%2F{}&dl=1"
-        path = osp.join("data", dataset)
+        path = osp.join(data_path, dataset)
         if not osp.exists(path):
             SAINTDataset(path, dataset, url)
-        super(FlickrDatset, self).__init__(path, dataset, url)
+        super(FlickrDataset, self).__init__(path, dataset, url)
         self.data = scale_feats(self.data)
 
     def get_evaluator(self):
-        return accuracy
+        return Accuracy()
 
     def get_loss_fn(self):
-        return cross_entropy_loss
+        return CrossEntropyLoss()
 
 
-@register_dataset("reddit")
 class RedditDataset(SAINTDataset):
-    def __init__(self):
+    def __init__(self, data_path="data"):
         dataset = "Reddit"
         url = "https://cloud.tsinghua.edu.cn/d/d087e7e766e747ce8073/files/?p=%2F{}&dl=1"
-        path = osp.join("data", dataset)
+        path = osp.join(data_path, dataset)
         if not osp.exists(path):
             SAINTDataset(path, dataset, url)
         super(RedditDataset, self).__init__(path, dataset, url)
         self.data = scale_feats(self.data)
 
     def get_evaluator(self):
-        return accuracy
+        return Accuracy()
 
     def get_loss_fn(self):
-        return cross_entropy_loss
+        return CrossEntropyLoss()
 
 
-@register_dataset("ppi")
 class PPIDataset(SAINTDataset):
-    def __init__(self):
+    def __init__(self, data_path="data"):
         dataset = "PPI"
         url = "https://cloud.tsinghua.edu.cn/d/2c6e94ec9dad4972b58e/files/?p=%2F{}&dl=1"
-        path = osp.join("data", dataset)
+        path = osp.join(data_path, dataset)
         if not osp.exists(path):
             SAINTDataset(path, dataset, url)
         super(PPIDataset, self).__init__(path, dataset, url)
         self.data = scale_feats(self.data)
 
     def get_evaluator(self):
-        return multilabel_f1
+        return MultiLabelMicroF1()
 
     def get_loss_fn(self):
-        return bce_with_logits_loss
+        return BCEWithLogitsLoss()
 
 
-@register_dataset("ppi-large")
 class PPILargeDataset(SAINTDataset):
-    def __init__(self):
+    def __init__(self, data_path="data"):
         dataset = "PPI_Large"
         url = "https://cloud.tsinghua.edu.cn/d/469ef38a520640bba267/files/?p=%2F{}&dl=1"
-        path = osp.join("data", dataset)
+        if data_path is None:
+            data_path = "data"
+        path = osp.join(data_path, dataset)
         if not osp.exists(path):
             SAINTDataset(path, dataset, url)
         super(PPILargeDataset, self).__init__(path, dataset, url)
         self.data = scale_feats(self.data)
 
     def get_evaluator(self):
-        return multilabel_f1
+        return MultiLabelMicroF1()
 
     def get_loss_fn(self):
-        return bce_with_logits_loss
+        return BCEWithLogitsLoss()
